@@ -113,7 +113,7 @@ trim_perc <- function(x, output) {
 #' @return formatted values
 #' @export
 perc_perc <- function(x, output) {
-  paste0(round(x[1] * 100, 1), "% (", round(x[2] * 100, 1), "%)")
+  paste0(new_round(x[1] * 100, 0), "% (", new_round(x[2] * 100, 0), "%)")
 }
 
 #' Format of xx.xx (xx.xx, xx.xx)
@@ -123,7 +123,7 @@ perc_perc <- function(x, output) {
 #' @return formatted values
 #' @export
 format_3d <- function(x, output) {
-  paste0(round(x[1], 2), " (", round(x[2], 2), ", ", round(x[3], 2), ")")
+  paste0(new_round(x[1], 2), " (", new_round(x[2], 2), ", ", new_round(x[3], 2), ")")
 }
 
 
@@ -160,7 +160,7 @@ s_surv_time_1 <- function(df, .var, is_event, control = control_surv_time()) {
   new_label <- paste0("Median (Months, ", conf_level * 100, "% CI)")
 
   list(
-    median_ci = with_label(c(
+    median_ci = formatters::with_label(c(
       unname(srv_tab["median"]),
       unname(srv_tab[paste0(srv_fit$conf.int, c("LCL", "UCL"))])
     ), new_label)
@@ -175,7 +175,6 @@ s_surv_time_1 <- function(df, .var, is_event, control = control_surv_time()) {
 #' @param long flag
 #' @return A function suitable for use in rtables::analyze() with element selection,
 #' reformatting, and relabeling performed automatically.
-#' @export
 s_proportion_1 <- function(x, conf_level = 0.95,
                            method = c(
                              "waldcc", "wald", "clopper-pearson",
@@ -206,7 +205,7 @@ s_proportion_1 <- function(x, conf_level = 0.95,
   )
 
   # rcell(c(p_hat, prop_ci), format = list(rsp_ci_format))
-  # prop_ci = with_label(c(p_hat * 100, prop_ci * 100), new_label)
+  # prop_ci = formatters::with_label(c(p_hat * 100, prop_ci * 100), new_label)
   list(
     "n_prop" = formatters::with_label(c(n, p_hat), "ORR (%)"),
     "prop_ci" = formatters::with_label(
@@ -232,8 +231,8 @@ s_coxph_pairwise_1 <- function(df, .ref_group, .in_ref_col, .var, is_event, stra
         rcell(""),
         .labels = c(paste0(strat_type, " HR (", conf_level * 100, "% CI)"), paste0("p-value (", pval_method, ")"))
       )
-      # list(hr_ci = with_label("", paste0("Stratified HR (", conf_level*100, "% CI)")),
-      #      pvalue = with_label("", paste0("p-value (", pval_method, ")"))
+      # list(hr_ci = formatters::with_label("", paste0("Stratified HR (", conf_level*100, "% CI)")),
+      #      pvalue = formatters::with_label("", paste0("p-value (", pval_method, ")"))
       #      )
     )
   }
@@ -262,13 +261,13 @@ s_coxph_pairwise_1 <- function(df, .ref_group, .in_ref_col, .var, is_event, stra
     likelihood = sum_cox$logtest["pvalue"]
   )
   list(
-    # hr = with_label(sum_cox$conf.int[1, 1], "Hazard Ratio"),
-    # hr_ci = with_label(unname(sum_cox$conf.int[1, 3:4]), f_conf_level(conf_level)),
-    hr_ci = with_label(
+    # hr = formatters::with_label(sum_cox$conf.int[1, 1], "Hazard Ratio"),
+    # hr_ci = formatters::with_label(unname(sum_cox$conf.int[1, 3:4]), f_conf_level(conf_level)),
+    hr_ci = formatters::with_label(
       c(sum_cox$conf.int[1, 1], unname(sum_cox$conf.int[1, 3:4])),
       paste0("Stratified HR (", conf_level * 100, "% CI)")
     ),
-    pvalue = with_label(unname(pval), paste0("p-value (", pval_method, ")"))
+    pvalue = formatters::with_label(unname(pval), paste0("p-value (", pval_method, ")"))
   )
 
   in_rows(
@@ -619,3 +618,8 @@ build_table_header <- function(anl,
 get_version_label_output <- function() {
   NULL
 }
+
+
+strip_NA <- function(input) {
+  return(input[which(input != "NA")])
+}
